AutoRez = AutoRez or {}
AutoRez.AddonId = "AutoRez"
AutoRez.Version = 1.3
AutoRez.ResurrectionLog = {}
AutoRez.CurrentZoneId = 0

local LAM2 = LibStub:GetLibrary("LibAddonMenu-2.0")

-------------------------------------------------------------------------------------------------
--  Menu Functions --
-------------------------------------------------------------------------------------------------
function AutoRez.CreateSettingsWindow()
    local panelData = {
        type = "panel",
        name = "AutoRez",
        displayName = "AutoRez",
        author = "Meai",
        version = "1.3.0",
        slashCommand = "/autorez",
        registerForRefresh = true,
        registerForDefaults = true,
    }

    local cntrlOptionsPanel = LAM2:RegisterAddonPanel("AutoRez_Settings", panelData)

    local optionsData = {
        [1] = {
            type = "header",
            name = "AutoRez Settings"
        },
        [2] = {
            type = "checkbox",
            name = "Accept ressurections",
            tooltip = "When ON you will automatically accept ressurections from players.",
            default = true,
            getFunc = function() return AutoRez.data.acceptRez end,
            setFunc = function(newValue)
                AutoRez.data.acceptRez = newValue end
        },
        [3] = {
            type = "checkbox",
            name = "Show who rezed you",
            tooltip = "*REQUIRES* Accept Ressurection to be ON. When ON it will show who rezed you in the chat window. When OFF it will not print who rezed you to the chat window.",
            default = true,
            getFunc = function() return AutoRez.data.showWhoRezedYouWhenRezed end,
            setFunc = function(newValue)
                AutoRez.data.showWhoRezedYouWhenRezed = newValue end
        },
        [4] = {
            type = "checkbox",
            name = "Show resurrection summary",
            tooltip = "*REQUIRES* Accept Ressurection to be ON. When ON it will print in chat window a summary of everyone who has rezes you and how many times. When OFF it will not print a summary to the chat window.",
            default = true,
            getFunc = function() return AutoRez.data.showSummaryWhenRezed end,
            setFunc = function(newValue)
                AutoRez.data.showSummaryWhenRezed = newValue end
        },
        [5] = {
            type = "checkbox",
            name = "Auto respawn at keep when captured",
            tooltip = "When ON and you are dead, it will automatically respawn you are the most recently captured keep.",
            default = true,
            getFunc = function() return AutoRez.data.autoRespawnAtNearestKeep end,
            setFunc = function(newValue)
                AutoRez.data.autoRespawnAtNearestKeep = newValue end
        }
    }

    LAM2:RegisterOptionControls("AutoRez_Settings", optionsData)
end

------------------------------------------------
--- Key Bindings
------------------------------------------------
function AutoRez:ToggleAcceptRez()
    AutoRez.data.acceptRez = not AutoRez.data.acceptRez

    if AutoRez.data.acceptRez == true then
        CENTER_SCREEN_ANNOUNCE:AddMessage(3, CSA_EVENT_SMALL_TEXT, SOUNDS.CHAMPION_POINTS_COMMITTED, "AutoRez ON")
        d("AutoRez ON")
    else
        CENTER_SCREEN_ANNOUNCE:AddMessage(3, CSA_EVENT_SMALL_TEXT, SOUNDS.CHAMPION_POINTS_COMMITTED, "AutoRez OFF")
        d("AutoRez OFF")
    end
end

function AutoRez:DisplayResurrectionLog()
    d("---AutoRez Summary---")
    local count = 0
    for requesterCharacterName,rezes in pairs(AutoRez.ResurrectionLog) do
        count = count + rezes
        d(requesterCharacterName.." "..rezes)
    end

    if count == 0 then
        d("No one has rezed you :-(")
    else
        d("Total: "..count)
    end
    d("-------------------------------")
end

------------------------------------------------
--- Event handlers
------------------------------------------------
function AutoRez.ResurrectReceived(eventCode, requesterCharacterName, timeLeftToAccept, requesterDisplayName)
    if AutoRez.data.acceptRez == true then
        AcceptResurrect()

        if AutoRez.ResurrectionLog[requesterCharacterName] == nil then
            AutoRez.ResurrectionLog[requesterCharacterName] = 1
        else
            AutoRez.ResurrectionLog[requesterCharacterName] = AutoRez.ResurrectionLog[requesterCharacterName] + 1
        end

        if AutoRez.data.showWhoRezedYouWhenRezed == true then
            d("Rezed by "..requesterCharacterName)
        end

        if AutoRez.data.showSummaryWhenRezed == true then
            AutoRez:DisplayResurrectionLog()
        end
    end
end

function AutoRez.KeepAllianceOwnerChanged( eventCode, keepId, battlegroundContext, owningAlliance, oldOwningAlliance)
    --Fort Warden       ???
    --Fort Rayles       ???
    --Fort Glademist    ???
    --Fort Dragonclaw   ???
    --Bruma             ???
    --Fort Aleswell     ???
    --Fort Ash          ???
    --Castle Brindle    ???
    --Vlastrus          ???
    --Bleaker's Outpost 134
    --Chalman Keep      ???
    --Kingscrest Keep   ???
    --Arrius Keep       ???
    --Farragut Keep     ???
    --Blue Road Keep    ???
    --Sejanus Outpost   ???
    --Castle Roeback    ???
    --Castle Alessia    ???
    --Drakelowe Keep    ???
    --Castle Faregyl    ???
    --Castle Black Boot ???
    --Castle Bloodmayne ???
    --Cropsford         ???
    --Nikel             ???

    --See if keep is close/in same zone

    --Respawn if close
    if owningAlliance == GetUnitAlliance("player") and
            IsUnitDead("player") and
            not IsUnitBeingResurrected("player") then
        AutoRez.RespawnIfPossible(keepId)
    end
end

function AutoRez.PlayerDead(eventCode)
    --Find nearest keepId
    --AutoRez.RespawnIfPossible(keepId)
end

function AutoRez.RespawnIfPossible(keepId)
    if AutoRez.data.autoRespawnAtNearestKeep then
        if CanRespawnAtKeep(keepId) then
            RespawnAtKeep(keepId)
        end
    end
end

------------------------------------------------
--- Initialization
------------------------------------------------
function AutoRez.init()
    if AutoRez.initDone then return end
    AutoRez.initDone = true

    local defaultGlobal = {
        acceptRez = true,
        showSummaryWhenRezed = true,
        showWhoRezedYouWhenRezed = true,
        autoRespawnAtNearestKeep = true
    }

    AutoRez.data = ZO_SavedVars:NewAccountWide("AutoRez_Data", AutoRez.Version, "Data", defaultGlobal)

    AutoRez.CreateSettingsWindow()
end

------------------------------------------------
--- Events
------------------------------------------------
EVENT_MANAGER:RegisterForEvent(AutoRez.AddonId, EVENT_ADD_ON_LOADED, AutoRez.init)
EVENT_MANAGER:RegisterForEvent(AutoRez.AddonId, EVENT_RESURRECT_REQUEST, AutoRez.ResurrectReceived)
EVENT_MANAGER:RegisterForEvent(AutoRez.AddonId, EVENT_KEEP_ALLIANCE_OWNER_CHANGED, AutoRez.KeepAllianceOwnerChanged)
EVENT_MANAGER:RegisterForEvent(AutoRez.AddonId, EVENT_PLAYER_DEAD, AutoRez.PlayerDead)